@@ -1,7 +1,7 @@
 package Weed::ArrayField;
 use Weed;
 
-our $VERSION = '0.012';
+our $VERSION = '0.009';
 
 sub SET_DESCRIPTION {
 	my ( $this, $description ) = @_;
@@ -16,32 +16,32 @@ use base 'X3DArray';
 use Weed::Tie::Value::Array;
 use Weed::Tie::ArrayLength;
 
-use overload '@{}' => sub { $_[0]->{array} };
+use overload '@{}' => 'getArray';
 
 #sub new { shift->X3DField::new(@_) }
 *new = \&X3DField::new;
 
-sub create {    # also in MFNode
-	my ($this) = @_;
+sub new_from_definition {    # also in MFNode
+	my $this = shift->X3DField::new_from_definition(@_);
 
-	die $this->getDefinition unless defined $this->getInitialValue;
-
-	$this->{value} = $this->getInitialValue->getClone;
 	$this->{array} = new Weed::Tie::Value::Array $this;
-
 	tie $this->{length}, 'Weed::Tie::ArrayLength', $this->{array};
 
-	return;
+	return $this;
 }
 
 #sub getClone { $_[0]->X3DField::getClone }
 #sub getCopy  { $_[0]->X3DField::getCopy }
 
+sub getInitialValue { $_[0]->getDefinition->getValue->getClone }
+
 sub getFieldType { $_[0]->X3DPackage::Scalar("FieldType") }
 
+sub getArray { ${ $_[0] }->{array} }
+
 sub setValue {
 	my $this  = shift;
-	my $array = $this->{array};
+	my $array = $this->getArray;
 
 	if ( 0 == @_ ) {
 		@$array = ();
@@ -64,9 +64,13 @@ sub setValue {
 	$this->X3DField::setValue( $this->getValue );
 }
 
-#sub set1Value { $_[0]->[ $_[1] ] = $_[2] }
+sub set1Value {
+	warn;
+}
 
-#sub get1Value { $_[0]->[ $_[1] ] }
+sub get1Value {
+	warn;
+}
 
 sub length : lvalue { $_[0]->{length} }
 
